/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *
 */

#ifndef TILESETMGR_H
#define TILESETMGR_H

#include "Plugin.h"
#include "Tile.h"
#include "System/DataStream.h"

class GEM_EXPORT TileSetMgr : public Plugin {
public:
	TileSetMgr(void);
	virtual ~TileSetMgr(void);
	virtual bool Open(DataStream* stream, bool autoFree = true) = 0;
	virtual Tile* GetTile(unsigned short* indexes, int count,
		unsigned short* secondary = NULL) = 0;
};

#endif
